#!/bin/bash

## 1st argument: directory for generated files
## 2nd argument: number of problems to generate

mkdir -p $1

for ((i=1; i<=$2; i++))
do
	filename=$1/$i.smt2
	tools/fuzzsmt "QF_BV" > $filename
	
	echo "Solving $filename..."
	
	echo -n "   Running Boolector..."
	SECONDS=0
	tools/boolector -rwl3 $filename -o $filename.out
	boolector_result=`cat $filename.out | grep -o -E 'sat|unsat|unknow'`
	if [ -z "$boolector_result" ]; then
		echo -n "   ERROR: "
		cat $filename.out
		continue
	elif [ $boolector_result = "unknown" ]; then
		echo "   returned unknown"
		continue
	fi
	echo "   $SECONDS s"
	
	echo -n "   Running BV2EPR..."
	SECONDS=0
	tools/bv2epr -rwl3 $filename -o $filename.p > /dev/null
	echo "   $SECONDS s"
	echo -n "   Running iProver..."
	SECONDS=0
	tools/iprover.sh $filename.p > $filename.out
	iprover_result=`cat $filename.out | grep -E -o 'Satisfiable|Unsatisfiable|Unknown'`
	echo "   $SECONDS s"
	
	if [ $boolector_result = "sat" -a $iprover_result = "Satisfiable" ]; then
		echo "   OK ($iprover_result)"
	elif [ $boolector_result = "unsat" -a $iprover_result = "Unsatisfiable" ]; then
		echo "   OK ($iprover_result)"
	else
		echo "   FAIL"
	fi
done
